From: Simon Ruderich <simon@ruderich.org>
Date: Sat, 17 Sep 2011 19:33:52 +0000 (+0200)
Subject: Rename server_certificate_path() to server_certificate_file().
X-Git-Url: https://ruderich.org/simon/gitweb/?a=commitdiff_plain;h=ceebf9e917885f33396b93504943d7b8e63e782b;p=tlsproxy%2Ftlsproxy.git

Rename server_certificate_path() to server_certificate_file().
---

diff --git a/src/verify.c b/src/verify.c
index 1df9b51..f546fd4 100644
--- a/src/verify.c
+++ b/src/verify.c
@@ -114,7 +114,7 @@ int verify_tls_connection(gnutls_session_t session, const char *hostname) {
     gnutls_x509_crt_deinit(cert);
 
     /* Open stored server certificate file. */
-    if (0 != server_certificate_path(&file, hostname, path, sizeof(path))) {
+    if (0 != server_certificate_file(&file, hostname, path, sizeof(path))) {
         LOG(LOG_DEBUG, "server certificate:\n%s", server_cert);
         return -1;
     }
@@ -196,12 +196,12 @@ int proxy_certificate_path(const char *hostname, char *path, size_t size) {
                                 hostname, path, size);
 }
 
-int server_certificate_path(FILE **file, const char *hostname,
+int server_certificate_file(FILE **file, const char *hostname,
                             char *path, size_t size) {
     if (0 != get_certificate_path(STORED_SERVER_CERT_FORMAT,
                                   hostname, path, size)) {
         LOG_PERROR(LOG_ERROR,
-                   "server_certificate_path(): failed to get path");
+                   "server_certificate_file(): failed to get path");
         return -1;
     }
 
@@ -210,11 +210,11 @@ int server_certificate_path(FILE **file, const char *hostname,
     if (NULL == *file) {
         if (global_passthrough_unknown) {
             LOG(LOG_DEBUG,
-                "server_certificate_path(): failed to open '%s': %s",
+                "server_certificate_file(): failed to open '%s': %s",
                 path, strerror(errno));
         } else {
             LOG(LOG_WARNING,
-                "server_certificate_path(): failed to open '%s': %s",
+                "server_certificate_file(): failed to open '%s': %s",
                 path, strerror(errno));
         }
         /* Couldn't open the file, special case. */
diff --git a/src/verify.h b/src/verify.h
index ebcd993..4935242 100644
--- a/src/verify.h
+++ b/src/verify.h
@@ -21,7 +21,7 @@
 #define VERIFY_H
 
 int proxy_certificate_path(const char *hostname, char *path, size_t size);
-int server_certificate_path(FILE **file, const char *hostname,
+int server_certificate_file(FILE **file, const char *hostname,
                             char *path, size_t size);
 
 int verify_tls_connection(gnutls_session_t session, const char *hostname);
diff --git a/src/connection.c b/src/connection.c
index f15f4c1..0a69f78 100644
--- a/src/connection.c
+++ b/src/connection.c
@@ -202,7 +202,7 @@ void handle_connection(int client_socket) {
         char path[1024];
         FILE *file = NULL;
 
-        if (-2 == server_certificate_path(&file, host, path, sizeof(path))) {
+        if (-2 == server_certificate_file(&file, host, path, sizeof(path))) {
             /* We've established a connection, tell the client. */
             fprintf(client_fd, "HTTP/1.0 200 Connection established\r\n");
             fprintf(client_fd, "\r\n");
@@ -218,7 +218,7 @@ void handle_connection(int client_socket) {
 
             goto out;
         }
         /* server_certificate_path() may have opened the file, close it. */
         if (NULL != file) {
             fclose(file);
         }
@@ -218,7 +218,7 @@ void handle_connection(int client_socket) {
             goto out;
         }
-        /* server_certificate_path() may have opened the file, close it. */
+        /* server_certificate_file() may have opened the file, close it. */
         if (NULL != file) {
             fclose(file);